<?php

/**
 * @file
 * Administrative page callbacks for the fullstory module.
 */

/**
 * Implements hook_admin_settings().
 */
function fullstory_admin_settings_form() {
  $form['fullstory'] = array(
    '#type' => 'vertical_tabs',
  );

  // General Settings.
  $form['general'] = array(
    '#type' => 'fieldset',
    '#title' => t('General settings'),
    '#collapsible' => FALSE,
    '#group' => 'fullstory',
  );
  $form['general']['fullstory_host'] = array(
    '#type' => 'textfield',
    '#title' => t('Host'),
    '#default_value' => variable_get('fullstory_host', 'fullstory.com'),
    '#size' => 20,
    '#maxlength' => 20,
    '#disabled' => TRUE,
    '#description' => t('For successful recording, this value should always be fullstory.com.'),
  );
  $form['general']['fullstory_script'] = array(
    '#type' => 'textfield',
    '#title' => t('Script'),
    '#default_value' => variable_get('fullstory_script', 'edge.fullstory.com/s/fs.js'),
    '#size' => 20,
    '#maxlength' => 20,
    '#disabled' => TRUE,
  );
  $form['general']['fullstory_org'] = array(
    '#type' => 'textfield',
    '#title' => t('ID'),
    '#default_value' => variable_get('fullstory_org', ''),
    '#size' => 20,
    '#maxlength' => 20,
    '#required' => TRUE,
    '#description' => t('The ID of the org or account into which data should be recorded.'),
  );
  $form['general']['fullstory_namespace'] = array(
    '#type' => 'textfield',
    '#title' => t('Namespace'),
    '#default_value' => variable_get('fullstory_namespace', 'FS'),
    '#size' => 20,
    '#maxlength' => 20,
    '#required' => TRUE,
    '#description' => t('Used to change the namespace for the FullStory API, to prevent namespace conflicts.'),
  );

  $form['general']['fullstory_sampling'] = array(
    '#type' => 'select',
    '#options' => array(
      1 => t('10%'),
      2 => t('20%'),
      3 => t('30%'),
      4 => t('40%'),
      5 => t('50%'),
      6 => t('60%'),
      7 => t('70%'),
      8 => t('80%'),
      9 => t('90%'),
      0 => t('100%'),
    ),
    '#default_value' => variable_get('fullstory_sampling', 0),
    '#title' => t('Percentage of eligible sessions to record'),
    '#description' => t('Optionally limit the number of sessions recorded by 
      FullStory to a random sample of all your eligible sessions.'),
  );

  $form['general']['fullstory_debug'] = array(
    '#type' => 'checkbox',
    '#title' => t('Turn on debug mode.'),
    '#default_value' => variable_get('fullstory_debug', 0),
    '#description' => t('Check this if you want to see detailed console logs, and lots of them.'),
  );

  // Role specific settings.
  $form['role_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Role specific script settings'),
    '#collapsible' => TRUE,
    '#group' => 'fullstory',
  );
  // Get all the roles.
  $roles = user_roles();
  $role_options = array();
  foreach ($roles as $rid => $name) {
    $role_options[$rid] = $name;
  }
  $form['role_settings']['fullstory_exclude_roles'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Remove script for specific roles'),
    '#default_value' => variable_get('fullstory_exclude_roles', array()),
    '#options' => $role_options,
    '#description' => t('Select any roles that should be excluded from FullStory recordings. If no roles are selected, all roles will be recorded.'),
  );

  // Page specific settings.
  $form['page_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Page specific script settings'),
    '#collapsible' => TRUE,
    '#group' => 'fullstory',
  );
  $form['page_settings']['fullstory_record_pages'] = array(
    '#type' => 'radios',
    '#title' => t('Add script to specific pages'),
    '#options' => array(
      t('Record every page except the listed pages.'),
      t('Record the listed pages only.'),
    ),
    '#default_value' => variable_get('fullstory_record_pages', 0),
  );
  $form['page_settings']['fullstory_pages'] = array(
    '#type' => 'textarea',
    '#title' => t('Pages'),
    '#default_value' => variable_get('fullstory_pages', ''),
    '#description' => t('Enter one page per line as Drupal paths. The "*" character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.', array(
      '%blog' => 'blog',
      '%blog-wildcard' => 'blog/*',
      '%front' => '<front>',
    )),
    '#wysiwyg' => FALSE,
  );

  return system_settings_form($form);
}
